==> create-fly-1.21.11-6.0.8-2-sources.jar: com/zurrtum/create/content/equipment/armor/AllArmorMaterials.java <==
package com.zurrtum.create.content.equipment.armor;

import com.google.common.collect.Maps;
import com.zurrtum.create.AllItemTags;
import java.util.Map;
import net.minecraft.class_10192;
import net.minecraft.class_10394;
import net.minecraft.class_1304;
import net.minecraft.class_1741;
import net.minecraft.class_1792;
import net.minecraft.class_3414;
import net.minecraft.class_3417;
import net.minecraft.class_3489;
import net.minecraft.class_5321;
import net.minecraft.class_6862;
import net.minecraft.class_6880;
import net.minecraft.class_8051;
import net.minecraft.class_9334;

public class AllArmorMaterials {
    public static final class_1741 COPPER = register(
        7,
        createDefenseMap(1, 3, 4, 2, 4),
        7,
        class_3417.field_14761,
        0.0F,
        0.0F,
        AllItemTags.REPAIRS_COPPER_ARMOR,
        AllEquipmentAssetKeys.COPPER
    );
    public static final class_1741 CARDBOARD = register(
        4,
        createDefenseMap(1, 1, 1, 1, 2),
        4,
        class_3417.field_14581,
        0.0F,
        0.0F,
        AllItemTags.REPAIRS_CARDBOARD_ARMOR,
        AllEquipmentAssetKeys.CARDBOARD
    );
    public static final class_1741 NETHERITE = register(
        37,
        createDefenseMap(3, 6, 8, 3, 11),
        15,
        class_3417.field_21866,
        3.0F,
        0.1F,
        class_3489.field_54064,
        AllEquipmentAssetKeys.NETHERITE
    );

    private static class_1741 register(
        int durability,
        Map<class_8051, Integer> defense,
        int enchantmentValue,
        class_6880<class_3414> equipSound,
        float toughness,
        float knockbackResistance,
        class_6862<class_1792> repairIngredient,
        class_5321<class_10394> assetId
    ) {
        return new class_1741(durability, defense, enchantmentValue, equipSound, toughness, knockbackResistance, repairIngredient, assetId);
    }

    private static Map<class_8051, Integer> createDefenseMap(
        int bootsDefense,
        int leggingsDefense,
        int chestplateDefense,
        int helmetDefense,
        int bodyDefense
    ) {
        return Maps.newEnumMap(Map.of(
            class_8051.field_41937,
            bootsDefense,
            class_8051.field_41936,
            leggingsDefense,
            class_8051.field_41935,
            chestplateDefense,
            class_8051.field_41934,
            helmetDefense,
            class_8051.field_48838,
            bodyDefense
        ));
    }

    public static class_1792.class_1793 chest(class_1741 material) {
        return new class_1792.class_1793().method_7889(1).method_57348(material.method_63993(class_8051.field_41935)).method_61649(material.comp_3167())
            .method_61647(material.comp_2301()).method_57349(
                class_9334.field_54196,
                class_10192.method_64202(class_1304.field_6174).method_64205(material.comp_2300()).method_64204(material.comp_3168()).method_64203()
            );
    }

    public static void register() {
    }
}

==> create-fly-6.0.7-1.21.8-19-sources.jar: com/zurrtum/create/content/equipment/armor/AllArmorMaterials.java <==
package com.zurrtum.create.content.equipment.armor;

import com.google.common.collect.Maps;
import com.zurrtum.create.AllItemTags;
import java.util.Map;
import net.minecraft.class_10192;
import net.minecraft.class_10394;
import net.minecraft.class_1304;
import net.minecraft.class_1741;
import net.minecraft.class_1792;
import net.minecraft.class_3414;
import net.minecraft.class_3417;
import net.minecraft.class_3489;
import net.minecraft.class_5321;
import net.minecraft.class_6862;
import net.minecraft.class_6880;
import net.minecraft.class_8051;
import net.minecraft.class_9334;

public class AllArmorMaterials {
    public static final class_1741 COPPER = register(
        7,
        createDefenseMap(1, 3, 4, 2, 4),
        7,
        class_3417.field_14761,
        0.0F,
        0.0F,
        AllItemTags.REPAIRS_COPPER_ARMOR,
        AllEquipmentAssetKeys.COPPER
    );
    public static final class_1741 CARDBOARD = register(
        4,
        createDefenseMap(1, 1, 1, 1, 2),
        4,
        class_3417.field_14581,
        0.0F,
        0.0F,
        AllItemTags.REPAIRS_CARDBOARD_ARMOR,
        AllEquipmentAssetKeys.CARDBOARD
    );
    public static final class_1741 NETHERITE = register(
        37,
        createDefenseMap(3, 6, 8, 3, 11),
        15,
        class_3417.field_21866,
        3.0F,
        0.1F,
        class_3489.field_54064,
        AllEquipmentAssetKeys.NETHERITE
    );

    private static class_1741 register(
        int durability,
        Map<class_8051, Integer> defense,
        int enchantmentValue,
        class_6880<class_3414> equipSound,
        float toughness,
        float knockbackResistance,
        class_6862<class_1792> repairIngredient,
        class_5321<class_10394> assetId
    ) {
        return new class_1741(durability, defense, enchantmentValue, equipSound, toughness, knockbackResistance, repairIngredient, assetId);
    }

    private static Map<class_8051, Integer> createDefenseMap(
        int bootsDefense,
        int leggingsDefense,
        int chestplateDefense,
        int helmetDefense,
        int bodyDefense
    ) {
        return Maps.newEnumMap(Map.of(
            class_8051.field_41937,
            bootsDefense,
            class_8051.field_41936,
            leggingsDefense,
            class_8051.field_41935,
            chestplateDefense,
            class_8051.field_41934,
            helmetDefense,
            class_8051.field_48838,
            bodyDefense
        ));
    }

    public static class_1792.class_1793 chest(class_1741 material) {
        return new class_1792.class_1793().method_57348(material.method_63993(class_8051.field_41935))
            .method_61649(material.comp_3167()).method_61647(material.comp_2301()).method_57349(
                class_9334.field_54196,
                class_10192.method_64202(class_1304.field_6174).method_64205(material.comp_2300()).method_64204(material.comp_3168()).method_64203()
            );
    }

    public static void register() {
    }
}
